==> openGion7.0.0.0_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GE33S.sql <==
/****************************************************************************/
/* GE33 ( ｸﾞﾙｰﾌﾟﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2017/01/05 15:19:11                                            */
/****************************************************************************/

CREATE TABLE GE33 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID   */
 , GROUP_ID     VARCHAR (  20 )                 NOT NULL            /*  20 ｸﾞﾙｰﾌﾟID */
 , ADDRESS      VARCHAR ( 256 )                 NOT NULL            /*  30 ｱﾄﾞﾚｽ    */
 , NAME_JA      VARCHAR ( 200 )                                     /*  40 名称     */
 , KBNAME       VARCHAR (   1 )                 NOT NULL            /*  50 名称区分 */
 , UNIQ         BIGINT                          NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR (  14 )                                     /* 820 登録日時 */
 , PGSET        VARCHAR (  10 )                                     /* 830 作成PG   */
 , PGPSET       VARCHAR (  10 )                                     /* 840 作成親PG */
 , USRSET       VARCHAR (  10 )                                     /* 850 作成社員 */
 , DYUPD        VARCHAR (  14 )                                     /* 860 更新日時 */
 , PGUPD        VARCHAR (  10 )                                     /* 870 更新PG   */
 , PGPUPD       VARCHAR (  10 )                                     /* 880 更新親PG */
 , USRUPD       VARCHAR (  10 )                                     /* 890 更新者   */
);


CREATE SEQUENCE GE33S00 ;


CREATE TRIGGER GE33T00 FOR GE33
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GE33S00,1 );
  END;

==> openGion7.2.0.0_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GE33S.sql <==
/****************************************************************************/
/* GE33 ( ｸﾞﾙｰﾌﾟﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2018/09/28 16:03:35                                            */
/****************************************************************************/

CREATE TABLE GE33 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID   */
 , GROUP_ID     VARCHAR (  20 )                 NOT NULL            /*  20 ｸﾞﾙｰﾌﾟID */
 , ADDRESS      VARCHAR ( 256 )                 NOT NULL            /*  30 ｱﾄﾞﾚｽ    */
 , NAME_JA      VARCHAR ( 200 )                                     /*  40 名称     */
 , KBNAME       VARCHAR (   1 )                 NOT NULL            /*  50 名称区分 */
 , UNIQ         BIGINT                          NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR (  14 )                                     /* 820 登録日時 */
 , PGSET        VARCHAR (  10 )                                     /* 830 作成PG   */
 , PGPSET       VARCHAR (  10 )                                     /* 840 作成親PG */
 , USRSET       VARCHAR (  10 )                                     /* 850 作成者   */
 , DYUPD        VARCHAR (  14 )                                     /* 860 更新日時 */
 , PGUPD        VARCHAR (  10 )                                     /* 870 更新PG   */
 , PGPUPD       VARCHAR (  10 )                                     /* 880 更新親PG */
 , USRUPD       VARCHAR (  10 )                                     /* 890 更新者   */
);


CREATE SEQUENCE GE33S00 ;


CREATE TRIGGER GE33T00 FOR GE33
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GE33S00,1 );
  END;
